@@ -11,15 +11,11 @@
 extern SEXP gbm_fit(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP gbm_plot(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP gbm_pred(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP gbm_shrink_gradient(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP gbm_shrink_pred(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
   {"gbm_fit",             (DL_FUNC) &gbm_fit,             22},
   {"gbm_plot",            (DL_FUNC) &gbm_plot,            10},
   {"gbm_pred",            (DL_FUNC) &gbm_pred,            10},
-  {"gbm_shrink_gradient", (DL_FUNC) &gbm_shrink_gradient, 11},
-  {"gbm_shrink_pred",     (DL_FUNC) &gbm_shrink_pred,     10},
   {NULL, NULL, 0}
 };
 
@@ -28,3 +24,4 @@ void R_init_gbm(DllInfo *dll)
   R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
 }
+
